## `raggy`

```python
pip install raggy
```

Read the [docs](https://zzstoatzz.github.io/raggy/)

### What is it?

A Python library for:

- scraping the web to produce rich documents
- putting these documents in vectorstores
- querying the vectorstores to find documents similar to a query

See this [example](https://github.com/zzstoatzz/raggy/blob/main/examples/chat_with_X/website.py) to chat with any website, or this [example](https://github.com/zzstoatzz/raggy/blob/main/examples/chat_with_X/repo.py) to chat with any GitHub repo.

### Contributing

We welcome contributions! See our [contributing guide](https://zzstoatzz.github.io/raggy/contributing) for details.
